"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
class Validator {
    constructor() {
        this.processing = false;
        this.successful = false;
        this.errors = {};
    }
    add(attribute, message) {
        if (this.missed(attribute)) {
            this.errors[attribute] = [];
        }
        if (!this.errors[attribute].includes(message)) {
            this.errors[attribute].push(message);
        }
    }
    has(field) {
        if ((0, util_1.isArray)(field)) {
            return (0, util_1.is)(Object.keys(this.errors), field);
        }
        let hasError = this.errors.hasOwnProperty(field);
        if (!hasError) {
            const errors = Object.keys(this.errors).filter((e) => e.startsWith(`${field}.`) || e.startsWith(`${field}[`));
            hasError = errors.length > 0;
        }
        return hasError;
    }
    first(field) {
        if (field instanceof Array) {
            for (let i = 0; i < field.length; i++) {
                if (!this.errors.hasOwnProperty(field[i])) {
                    continue;
                }
                return this.first(field[i]);
            }
        }
        return this.get(field)[0];
    }
    missed(field) {
        return !this.has(field);
    }
    nullState(field) {
        return this.has(field) ? this.missed(field) : null;
    }
    any(fields = [], returnObject) {
        if (returnObject) {
            const errors = {};
            if (!fields.length) {
                return {};
            }
            fields.forEach((key) => (errors[key] = this.get(key)));
            return errors;
        }
        if (!fields.length) {
            return Object.keys(this.errors).length > 0;
        }
        const errors = {};
        fields.forEach((key) => (errors[key] = this.get(key)));
        return Object.keys(errors).length > 0;
    }
    get(field) {
        return this.errors[field] || [];
    }
    all() {
        return this.errors;
    }
    count() {
        return Object.keys(this.errors).length;
    }
    fill(errors) {
        for (const error in errors) {
            if (!errors.hasOwnProperty(error)) {
                continue;
            }
            if (!(errors[error] instanceof Array)) {
                errors[error] = [errors[error]];
            }
        }
        this.errors = errors;
    }
    flush() {
        this.errors = {};
    }
    clear(attribute) {
        if (!attribute) {
            return this.flush();
        }
        const errors = Object.assign({}, this.errors);
        if (attribute instanceof Array) {
            attribute.map((field) => {
                Object.keys(errors)
                    .filter((e) => e === field ||
                    e.startsWith(`${field}.`) ||
                    e.startsWith(`${field}[`))
                    .forEach((e) => delete errors[e]);
            });
        }
        else {
            Object.keys(errors)
                .filter((e) => e === attribute ||
                e.startsWith(`${attribute}.`) ||
                e.startsWith(`${attribute}[`))
                .forEach((e) => delete errors[e]);
        }
        this.fill(errors);
    }
    isValid() {
        return !this.any();
    }
    onKeydown(event, prefix) {
        const { name } = event.target;
        if (!name)
            return;
        const name2 = prefix ? `${prefix}.${name}` : null;
        this.clear([name, name2]);
    }
}
exports.default = new Validator();
