"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.is = exports.cloneDeep = exports.merge = exports.isFile = exports.isArray = void 0;
function isArray(object) {
    return Object.prototype.toString.call(object) === '[object Array]';
}
exports.isArray = isArray;
function isFile(object) {
    if (typeof window === 'undefined') {
        return false;
    }
    if (typeof File !== 'function' || typeof FileList !== 'function') {
        return false;
    }
    return object instanceof File || object instanceof FileList;
}
exports.isFile = isFile;
function merge(a, b) {
    for (const key in b) {
        if (Object.prototype.hasOwnProperty.call(b, key)) {
            a[key] = cloneDeep(b[key]);
        }
    }
    return a;
}
exports.merge = merge;
function cloneDeep(object) {
    if (object === null) {
        return null;
    }
    if (isFile(object)) {
        return object;
    }
    if (isArray(object)) {
        const clone = [];
        for (const key in object) {
            if (Object.prototype.hasOwnProperty.call(object, key)) {
                clone[key] = cloneDeep(object[key]);
            }
        }
        return clone;
    }
    if (typeof object === 'object') {
        const clone = {};
        for (const key in object) {
            if (Object.prototype.hasOwnProperty.call(object, key)) {
                clone[key] = cloneDeep(object[key]);
            }
        }
        return clone;
    }
    return object;
}
exports.cloneDeep = cloneDeep;
function is(errors, error) {
    return isArray(error)
        ? error.some((w) => is(errors, w))
        : errors.includes(error);
}
exports.is = is;
